@@ -7,14 +7,14 @@
 /* ########################### */
 
 /* 
- # Last Modified:  $Date: 2002/07/23 19:34:58 $                  
+ # Last Modified:  $Date: 2008/04/24 13:05:58 $                  
  # by:             $Author: joe $              
 */
 
 
-/*  rpl v1.4.0 by Joe Laffey, LAFFEY Computer Imaging. 							*/
+/*  rpl v1.4.1 by Joe Laffey, LAFFEY Computer Imaging. 							*/
 /*  Visit http://www.laffeycomputer.com for updates 								*/
-/*  This software is copyright 1998, 1999, 2000, 2001 by Joe Laffey.   				*/
+/*  This software is copyright 1998-2008 by Joe Laffey.   				*/
     
 /*  Permission is granted to any individual, institution, or company to use, 		*/
 /*  copy, or redistribute rpl in source code or binary form so long as it is 		*/
@@ -984,7 +984,7 @@ int main(int argc, char** argv)
 /* values of some vars to stderr      */
 /* for the user to see...             */
 /* (Take too many params!)            */
-static void EchoModes(int escapeInput, int ignore_case, int whole_words, int simulationMode, char* searchString, char* replaceString, char* orgSearchString, char* orgReplaceString)
+static void EchoModes(int escapeInput, int ignore_case, int whole_words, int simulationMode, unsigned char* searchString, unsigned char* replaceString, unsigned char* orgSearchString, unsigned char* orgReplaceString)
 {
 	int i;
 	
